import { useUnit } from "effector-react";
import { useCallback } from "react";
import { $auth, loginFx, logoutFx } from "./model";

export const useAuth = () => {
  const { user, isAuthenticated, isLoading, error, manuallyLoggedOut } =
    useUnit($auth);

  const login = useCallback(async () => {
    try {
      await loginFx();
      return true;
    } catch (err) {
      return false;
    }
  }, []);

  const logout = useCallback(async () => {
    try {
      await logoutFx();
      return true;
    } catch (err) {
      return false;
    }
  }, []);

  const hasRole = useCallback(
    (role: string) => {
      return user?.roles.includes(role) || false;
    },
    [user],
  );

  return {
    user,
    isAuthenticated,
    isLoading,
    error,
    manuallyLoggedOut,
    login,
    logout,
    hasRole,
  };
};
