/* generated using openapi-typescript-codegen -- do not edit */
/* istanbul ignore file */
/* tslint:disable */
/* eslint-disable */
import type { authenticationResultDto } from '../models/authenticationResultDto';
import type { authHeaderResponseDto } from '../models/authHeaderResponseDto';
import type { sessionIpResponseDto } from '../models/sessionIpResponseDto';
import type { sessionStatusDto } from '../models/sessionStatusDto';
import type { signedAuthDocumentDto } from '../models/signedAuthDocumentDto';
import type { startSessionResponseDto } from '../models/startSessionResponseDto';
import type { CancelablePromise } from '../core/CancelablePromise';
import { OpenAPI } from '../core/OpenAPI';
import { request as __request } from '../core/request';
export class AuthenticationService {
    /**
     * Create a new QR authentication session.
     * This endpoint creates a new authentication session for QR-based authentication.
     * It generates a unique session ID and records the client's IP address.
     * The web client uses this information to generate a QR code that can be scanned by a mobile app.
     * @returns startSessionResponseDto OK
     * @throws ApiError
     */
    public static postApiAuthQrSession(): CancelablePromise<startSessionResponseDto> {
        return __request(OpenAPI, {
            method: 'POST',
            url: '/api/auth/qr/session',
            errors: {
                400: `Bad Request`,
            },
        });
    }
    /**
     * Get the client IP address for a session.
     * This endpoint is used by the mobile app after scanning a QR code.
     * It retrieves the client IP address associated with the session ID.
     * The mobile app uses this IP address when creating the authentication document.
     * @returns sessionIpResponseDto OK
     * @throws ApiError
     */
    public static getApiAuthQrSessionIp({
        sessionId,
    }: {
        sessionId: string,
    }): CancelablePromise<sessionIpResponseDto> {
        return __request(OpenAPI, {
            method: 'GET',
            url: '/api/auth/qr/session/{sessionId}/ip',
            path: {
                'sessionId': sessionId,
            },
            errors: {
                400: `Bad Request`,
                404: `Not Found`,
            },
        });
    }
    /**
     * Get the status of a QR authentication session.
     * This endpoint allows the web client to poll for the status of an authentication session.
     * It returns the current state of the session (pending, authenticated, expired, or invalidated).
     * The web client uses this to detect when the mobile app completes authentication.
     * @returns sessionStatusDto OK
     * @throws ApiError
     */
    public static getApiAuthQrSessionStatus({
        sessionId,
    }: {
        sessionId: string,
    }): CancelablePromise<sessionStatusDto> {
        return __request(OpenAPI, {
            method: 'GET',
            url: '/api/auth/qr/session/{sessionId}/status',
            path: {
                'sessionId': sessionId,
            },
            errors: {
                400: `Bad Request`,
                404: `Not Found`,
            },
        });
    }
    /**
     * Get the authentication header for a QR authentication session.
     * This endpoint allows the web client to poll for the authentication header of a session.
     * It returns the X-Signed-Auth header value that can be used to authenticate requests.
     * The web client uses this to make authenticated requests after the mobile app completes authentication.
     * @returns authHeaderResponseDto OK
     * @throws ApiError
     */
    public static getApiAuthQrSessionHeader({
        sessionId,
    }: {
        sessionId: string,
    }): CancelablePromise<authHeaderResponseDto> {
        return __request(OpenAPI, {
            method: 'GET',
            url: '/api/auth/qr/session/{sessionId}/header',
            path: {
                'sessionId': sessionId,
            },
            errors: {
                400: `Bad Request`,
                403: `Forbidden`,
                404: `Not Found`,
            },
        });
    }
    /**
     * Authenticate with a signed authentication document.
     * This endpoint accepts a signed authentication document from the mobile app.
     * It verifies the signature, checks that the client IP matches, and validates the document's validity period.
     * Upon successful verification, it marks the session as authenticated and returns a success result.
     * @returns authenticationResultDto OK
     * @throws ApiError
     */
    public static postApiAuthQrAuthenticate({
        requestBody,
    }: {
        requestBody?: signedAuthDocumentDto,
    }): CancelablePromise<authenticationResultDto> {
        return __request(OpenAPI, {
            method: 'POST',
            url: '/api/auth/qr/authenticate',
            body: requestBody,
            mediaType: 'application/json',
            errors: {
                400: `Bad Request`,
                404: `Not Found`,
            },
        });
    }
}
