/**
 * Get the base path for the application
 * @returns The base path
 */
export const getBasePath = (): string =>
  window.appConfig?.basePath || import.meta.env.VITE_BASE_PATH || "";

/**
 * Get an asset path with the base path prepended
 * @param path The asset path
 * @returns The asset path with the base path prepended
 */
export const getAssetPath = (path: string): string => {
  const basePath = getBasePath();
  return `${basePath}${path.startsWith("/") ? path : `/${path}`}`;
};
